@@ -8,7 +8,7 @@ async fn main() -> Result<(), RedisError> {
   // the max size isn't a hard limit - it just determines the size of the client array when the pool is initialized
   let pool = DynamicRedisPool::new(config, None, 5, 10);
 
-  let _ = pool.connect();
+  let _ = pool.connect().await;
   let _ = pool.wait_for_connect().await?;
 
   // modify the size of the pool at runtime
