@@ -1,6 +1,6 @@
 use fred::client::RedisClient;
 use fred::error::RedisError;
-use fred::types::RedisConfig;
+use fred::types::{RedisConfig, RedisValue};
 
 pub async fn should_run_get_set_trx(client: RedisClient, _config: RedisConfig) -> Result<(), RedisError> {
   let trx = client.multi(true).await?;
@@ -39,3 +39,15 @@ pub async fn should_fail_with_blocking_cmd(client: RedisClient, _: RedisConfig)
 
   Ok(())
 }
+
+pub async fn should_use_cluster_slot_with_publish(client: RedisClient, _: RedisConfig) -> Result<(), RedisError> {
+  let trx = client.multi(true).await?;
+
+  let res: RedisValue = trx.set("foo1", "bar", None, None, false).await?;
+  assert!(res.is_queued());
+  let res2: RedisValue = trx.publish("foo2", "bar").await?;
+  assert!(res2.is_queued());
+
+  let _: () = trx.exec().await?;
+  Ok(())
+}
